@@ -4,14 +4,28 @@
  *  License: MIT (See the LICENSE file in the repository root directory)
  */
 
-use std::{collections::VecDeque, fs::{self, remove_dir_all}, io::Write, path::{Path, PathBuf}};
+use std::{
+    collections::VecDeque,
+    fs::{self, remove_dir_all},
+    io::Write,
+    path::{Path, PathBuf},
+};
 
 use exitfailure::ExitFailure;
 use glob::glob;
 
-use crate::{constants::{
+use crate::{
+    constants::{
         PREFIX_AC_FILES, PREFIX_RTE_FILES, PREFIX_TLE_FILES, PREFIX_WA_FILES, TEST_CASES_FOLDER,
-    }, error::handle_error::{throw_couldnt_create_folder_msg, throw_couldnt_open_file_msg, throw_couldnt_write_to_file_msg, throw_extension_not_supported_msg, throw_program_not_installed_msg}, runner::types::{Language, is_extension_supported}, util::file::file_exists};
+    },
+    error::handle_error::{
+        throw_couldnt_create_folder_msg, throw_couldnt_open_file_msg,
+        throw_couldnt_write_to_file_msg, throw_extension_not_supported_msg,
+        throw_program_not_installed_msg,
+    },
+    runner::types::{is_extension_supported, Language},
+    util::file::file_exists,
+};
 
 pub fn remove_files(files: Vec<&str>) {
     for file in files {
@@ -79,6 +93,10 @@ pub fn save_test_case(file_name: &str, from_path: &str) {
     if write_file(file_name, fs::read_to_string(from_path).unwrap().as_bytes()).is_ok() {}
 }
 
+pub fn save_test_case_output(file_name: &str, from_path: &str) {
+    if write_file(file_name, fs::read_to_string(from_path).unwrap().as_bytes()).is_ok() {}
+}
+
 pub fn copy_file(from: &str, to: &str) -> Result<(), ExitFailure> {
     if let Some(data) = read_file(from) {
         write_file(to, data.as_bytes())?;
@@ -89,8 +107,8 @@ pub fn copy_file(from: &str, to: &str) -> Result<(), ExitFailure> {
 pub fn is_extension_supported_or_error(file_name: &str) -> Result<(), ExitFailure> {
     let path = Path::new(&file_name);
     let ext = match path.extension() {
-        Some(p) =>  p.to_str().unwrap_or(&""),
-        _ => &""
+        Some(p) => p.to_str().unwrap_or(&""),
+        _ => &"",
     };
     if !is_extension_supported(&ext) {
         return throw_extension_not_supported_msg(&file_name, &ext);
@@ -106,8 +124,32 @@ pub fn can_run_language_or_error(lang: &dyn Language) -> Result<(), ExitFailure>
     Ok(())
 }
 
-pub fn load_testcases(
+pub fn load_testcases_from_prefix_with_folder(
     queue: &mut VecDeque<PathBuf>,
+    folder: &str,
+    prefix: &str,
+) -> Result<(), ExitFailure> {
+    let paths = glob(&format!("{}/{}*", folder, prefix))?;
+    for path in paths.flatten() {
+        queue.push_back(path);
+    }
+    Ok(())
+}
+
+pub fn load_testcases_from_prefix(
+    queue: &mut VecDeque<PathBuf>,
+    prefix: &str,
+) -> Result<(), ExitFailure> {
+    let paths = glob(&format!("{}*", prefix))?;
+    for path in paths.flatten() {
+        queue.push_back(path);
+    }
+    Ok(())
+}
+
+pub fn load_testcases_from_states(
+    queue: &mut VecDeque<PathBuf>,
+    folder: &str,
     run_all: bool,
     run_ac: bool,
     run_wa: bool,
@@ -127,32 +169,47 @@ pub fn load_testcases(
     }
 
     if run_ac {
-        let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_AC_FILES))?;
-        for path in paths.flatten() {
-            queue.push_back(path);
-        }
+        load_testcases_from_prefix_with_folder(queue, folder, PREFIX_AC_FILES)?;
     }
 
     if run_wa {
-        let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_WA_FILES))?;
-        for path in paths.flatten() {
-            queue.push_back(path);
-        }
+        load_testcases_from_prefix_with_folder(queue, folder, PREFIX_WA_FILES)?;
     }
 
     if run_tle {
-        let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_TLE_FILES))?;
-        for path in paths.flatten() {
-            queue.push_back(path);
-        }
+        load_testcases_from_prefix_with_folder(queue, folder, PREFIX_TLE_FILES)?;
     }
 
     if run_rte {
-        let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_RTE_FILES))?;
-        for path in paths.flatten() {
-            queue.push_back(path);
-        }
+        load_testcases_from_prefix_with_folder(queue, folder, PREFIX_RTE_FILES)?;
     }
 
     Ok(())
 }
+
+pub fn get_filename_output(prefix: &str, filename: &str) -> String {
+    // prefix:   examples/run/test_cases/testcase_ac
+    // filename: testcase_ac_01.txt
+    // output: examples/run/test_cases/out_testcase_ac_01.txt
+
+    let prefix_clone = prefix.to_string();
+    let mut prefix_token = prefix_clone.split('/').collect::<Vec<&str>>();
+
+    // Check what filename is empty
+    // if prefix_token.is_empty() {
+    //     return throw_filename_cannot_be_empty();
+    // }
+
+    let _ = prefix_token.pop();
+
+    let mut path = String::new();
+
+    for (i, &item) in prefix_token.iter().enumerate() {
+        if i > 0 {
+            path.push('/');
+        }
+        path.push_str(item);
+    }
+
+    format!("{}/out_{}", path, filename)
+}
