@@ -14,7 +14,11 @@ use crate::error::handle_error::{
     throw_break_found_msg, throw_compiler_error_msg, throw_runtime_error_msg,
     throw_time_limit_exceeded_msg,
 };
-use crate::file_handler::file::{can_run_language_or_error, copy_file, create_folder_or_error, file_exists_or_error, format_filename_test_case, is_extension_supported_or_error, load_testcases, remove_files, remove_folder, save_test_case};
+use crate::file_handler::file::{
+    can_run_language_or_error, copy_file, create_folder_or_error, file_exists_or_error,
+    format_filename_test_case, is_extension_supported_or_error, load_testcases_from_states,
+    remove_files, remove_folder, save_test_case,
+};
 use crate::file_handler::path::get_root_path;
 use crate::generator::generator::execute_generator;
 use crate::painter::style::{
@@ -108,7 +112,7 @@ pub fn run(
     );
     let any_checker: Box<dyn Language> = any_checker.unwrap();
     let checker_file_lang_lang: &dyn Language = any_checker.as_ref();
-    
+
     // verify that the program to run the checker file is installed
     can_run_language_or_error(checker_file_lang_lang)?;
 
@@ -133,7 +137,15 @@ pub fn run(
     }
 
     let mut cases: VecDeque<PathBuf> = VecDeque::new();
-    load_testcases(&mut cases, run_all, run_ac, run_wa, run_tle, run_rte)?;
+    load_testcases_from_states(
+        &mut cases,
+        TEST_CASES_FOLDER,
+        run_all,
+        run_ac,
+        run_wa,
+        run_tle,
+        run_rte,
+    )?;
 
     let mut tle_count: u32 = 0;
     let mut wa_count: u32 = 0;
