@@ -15,7 +15,11 @@ use exitfailure::ExitFailure;
 
 // local library
 use crate::error::handle_error::throw_compiler_error_msg;
-use crate::file_handler::file::{can_run_language_or_error, copy_file, create_folder_or_error, file_exists_or_error, format_filename_test_case, is_extension_supported_or_error, load_testcases, remove_files, remove_files_with_prefix, remove_folder, save_test_case};
+use crate::file_handler::file::{
+    can_run_language_or_error, copy_file, create_folder_or_error, file_exists_or_error,
+    format_filename_test_case, is_extension_supported_or_error, load_testcases_from_states,
+    remove_files, remove_files_with_prefix, remove_folder, save_test_case,
+};
 use crate::file_handler::path::get_root_path;
 use crate::generator::generator::execute_generator;
 use crate::painter::style::{
@@ -106,7 +110,15 @@ pub fn run(
     }
 
     let mut cases: VecDeque<PathBuf> = VecDeque::new();
-    load_testcases(&mut cases, run_all, run_ac, run_wa, run_tle, run_rte)?;
+    load_testcases_from_states(
+        &mut cases,
+        TEST_CASES_FOLDER,
+        run_all,
+        run_ac,
+        run_wa,
+        run_tle,
+        run_rte,
+    )?;
 
     let mut tle_count: u32 = 0;
     let mut rte_count: u32 = 0;
