@@ -8,6 +8,8 @@ use std::process::Command;
 
 use crate::util::test_constants::{FOLDER, FOLDER_CHECK, FOLDER_CMP, FOLDER_TLE};
 
+use super::test_constants::FOLDER_RUN;
+
 pub fn execute_command_tle(cmd: &mut Command, target_file: &str, gen_file: &str, cases: usize) {
     cmd.arg("tle")
         .arg("--target-file")
@@ -53,3 +55,11 @@ pub fn execute_command_check(
         .arg("--timeout=1000")
         .arg(format!("--test-cases={}", cases));
 }
+
+pub fn execute_command_run(cmd: &mut Command, target_file: &str, prefix: &str) {
+    cmd.arg("run")
+        .arg("--target-file")
+        .arg(format!("{}/{}/{}", FOLDER, FOLDER_RUN, target_file))
+        .arg(format!("--prefix={}/{}/{}", FOLDER, FOLDER_RUN, prefix))
+        .arg("--timeout=1000");
+}
\ No newline at end of file
